
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.lang.reflect.Method;
import java.rmi.*;

public class RmiUtils {

//~ ============================================= Static fields/initializers \

    private static final Log logger = LogFactory.getLog(RmiUtils.class);

//~ ======================================================== Instance fields

//~ =========================================================== Constructors

//~ ============================================================= Properties

//~ ================================================================ Methods

    public static Exception convertRmiAccessException(Method method,
                                                      RemoteException ex, boolean isConnectFailure,
                                                      String serviceName) {

        if (logger.isDebugEnabled()) {
            logger.debug("Remote service [" + serviceName + "] threw exception", ex);
        }
        if (ReflectionUtils.declaresException(method, ex.getClass())) {
            return ex;
        } else {
            if (isConnectFailure) {
                return new RemoteConnectFailureException("Could not connect to remote service [" + serviceName + "]", ex);
            } else {
                return new RemoteAccessException("Could not access remote service [" + serviceName + "]", ex);
            }
        }
    }

    public static boolean isConnectFailure(RemoteException ex) {
        return (ex instanceof ConnectException
                || ex instanceof ConnectIOException
                || ex instanceof UnknownHostException
                || ex instanceof NoSuchObjectException
                || ex instanceof StubNotFoundException
                || ex instanceof MarshalException
                || ex instanceof UnmarshalException);
    }
}
